package dev.fyloz.colorrecipesexplorer.service.files

import dev.fyloz.colorrecipesexplorer.utils.FilePath
import mu.KotlinLogging

object FileExistCache {
    private val logger = KotlinLogging.logger {}
    private val map = hashMapOf<String, Boolean>()

    /** Checks if the given [path] is in the cache. */
    operator fun contains(path: FilePath) =
        path.path in map

    /** Checks if the file at the given [path] exists. */
    fun exists(path: FilePath) =
        map[path.path] ?: false

    /** Sets the file at the given [path] as existing. */
    fun setExists(path: FilePath) =
        set(path, true)

    /** Sets the file at the given [path] as not existing. */
    fun setDoesNotExists(path: FilePath) =
        set(path, false)

    /** Sets if the file at the given [path] [exists]. */
    fun set(path: FilePath, exists: Boolean) {
        map[path.path] = exists

        logger.debug("Updated FileExistCache state: ${path.path} -> $exists")
    }
}